@@ -12,6 +12,8 @@
 #'
 #' @examples
 #'
+#' suppressPackageStartupMessages(library("dplyr"))
+#'
 #' datasets::mtcars %>% distinct_se(c("cyl", "gear"))
 #'
 #' @export
@@ -19,5 +21,5 @@
 distinct_se <- function(.data, groupingVars, .keep_all = FALSE) {
   # convert char vector into spliceable vector
   groupingSyms <- rlang::syms(groupingVars)
-  distinct(.data = .data, !!!groupingSyms, .keep_all = .keep_all)
+  dplyr::distinct(.data = .data, !!!groupingSyms, .keep_all = .keep_all)
 }
