@@ -19,6 +19,6 @@
 group_indices_se <- function(.data, groupingVars, add = FALSE) {
   # convert char vector into spliceable vector
   groupingSyms <- rlang::syms(groupingVars)
-  group_indices(.data = .data, !!!groupingSyms, add = add)
+  dplyr::group_indices(.data = .data, !!!groupingSyms, add = add)
 }
 
