@@ -12,6 +12,8 @@
 #'
 #' @examples
 #'
+#' suppressPackageStartupMessages(library("dplyr"))
+#'
 #' datasets::iris %>%
 #'   transmute_se(c("Sepal_Long" := "Sepal.Length >= 2 * Sepal.Width",
 #'               "Petal_Short" := "Petal.Length <= 3.5")) %>%
@@ -23,7 +25,11 @@
 transmute_se <- function(.data, transmuteTerms) {
   # convert char vector into spliceable vector
   # from: https://github.com/tidyverse/rlang/issues/116
+  env <- parent.frame()
   transmuteQ <- lapply(transmuteTerms,
-                    function(si) { rlang::parse_expr(si) })
-  transmute(.data = .data, !!!transmuteQ)
+                       function(si) {
+                         rlang::parse_quosure(si,
+                                              env = env)
+                       })
+  dplyr::transmute(.data = .data, !!!transmuteQ)
 }
